/**
 * @author      Kelvin Hui
 * @see       	it-blogs.com
 * @since     	01-Jan-2016
 *
 * Reference : 	https://material.angularjs.org
 *				http://www.sitepoint.com/creating-crud-app-minutes-angulars-resource/
 */
angular.module('AngularApp.controllers',[])

	.controller('HeaderController', function ($scope, $timeout, $mdSidenav) {
		$scope.toggleLeft = buildDelayedToggler('leftMenu');
		$scope.triggerMenu = function () {	
			$mdSidenav('leftMenu').toggle();
		}; 
	
		function debounce(func, wait, context) {
			var timer;
			return function debounced() {
				var context = $scope, args = Array.prototype.slice.call(arguments);
				$timeout.cancel(timer);
				timer = $timeout(function() {
					timer = undefined;
					func.apply(context, args);
				}, wait || 10);
			};
		}
		function buildDelayedToggler(navID) {
			return debounce(function() {
				$mdSidenav(navID).toggle();
			}, 200);
		}
		function buildToggler(navID) {
			return function() {
				$mdSidenav(navID).toggle();
			}
		}
	})
  
	.controller('MenuController', function ($scope,menuService) {
		$scope.close = function () {
			menuService.close();
		};			
	})

	.controller('HomeController',function($scope,$stateParams,menuService){
		console.log("HomeController start...");
		
		menuService.close();
	})
	
	.controller('CompanyListController',function($scope,$state,Company,menuService){
		console.log("CompanyListController start...");
		
		menuService.close();
		$scope.companies=Company.query();
	})
	.controller('CompanyEditController',function($scope,$state,$stateParams,Company){
		console.log("CompanyEditController start...");
		
		$scope.update=function(){
			$scope.company.$update(function(){
				$scope.showMsg = true;
			});
		};
		$scope.load=function(){
			$scope.company=Company.get({id:$stateParams.id});
		};

		$scope.load();
	})
	
	.controller('CustomerListController',function($scope,$state,$window,showDialogService,Customer,menuService){
		console.log("CustomerListController start...");

		$scope.delete=function(customer){
			if(showDialogService.showDialog('Do you confirm to delete?')){
				customer.$delete(function(){
					$scope.customers=Customer.query();
				});
			}
		};
		
		menuService.close();	
		$scope.customers=Customer.query();
	})
	.controller('CustomerNewController',function($scope,$state,$stateParams,Customer,menuService){
		console.log("CustomerNewController start...");

		$scope.add=function(){
			$scope.customer.$save(function(){
				$scope.showMsg = true;
			});
		};

		menuService.close();
		$scope.customer=new Customer();
	})
	.controller('CustomerEditController',function($scope,$state,$stateParams,Customer){
		console.log("CustomerEditController start...");
		
		$scope.update=function(){
			$scope.customer.$update(function(){
				$scope.showMsg = true;
			});
		};
		$scope.load=function(){
			$scope.customer=Customer.get({id:$stateParams.id});
		};

		$scope.load();
	})
	
	.controller('ProductListController',function($scope,$state,$window,showDialogService,Product,menuService){
		console.log("ProductListController start...");
		
		$scope.delete=function(product){
			if(showDialogService.showDialog('Do you confirm to delete?')){
				product.$delete(function(){
					$scope.products=Product.query();
				});
			}
		};
		
		menuService.close();	
		$scope.products=Product.query();
	})
	.controller('ProductNewController',function($scope,$state,$stateParams,Product,menuService){
		console.log("ProductNewController start...");

		$scope.add=function(){
			$scope.product.$save(function(){
				$scope.showMsg = true;
			});
		};

		menuService.close();	
		$scope.product=new Product();
	})
	.controller('ProductEditController',function($scope,$state,$stateParams,Product){
		console.log("ProductEditController start...");
		
		$scope.update=function(){
			$scope.product.$update(function(){
				$scope.showMsg = true;
			});
		};
		$scope.load=function(){
			$scope.product=Product.get({id:$stateParams.id});
		};

		$scope.load();
	})
	
	.controller('PromotionListController',function($scope,$state,$window,showDialogService,Promotion,menuService){
		console.log("PromotionListController start...");
		
		$scope.delete=function(promotion){
			if(showDialogService.showDialog('Do you confirm to delete?')){
				promotion.$delete(function(){
					$scope.promotions=Promotion.query();
				});
			}
		};

		menuService.close();
		$scope.promotions=Promotion.query();
	})
	.controller('PromotionNewController',function($scope,$state,$stateParams,Promotion,menuService){
		console.log("PromotionNewController start...");
		
		$scope.add=function(){
			$scope.promotion.$save(function(){
				$scope.showMsg = true;
			});
		};
		
		menuService.close();		
		$scope.promotion=new Promotion();
	})
	.controller('PromotionEditController',function($scope,$state,$stateParams,$filter,Promotion){
		console.log("PromotionEditController start...");

		$scope.formatDatetime=function(){
			$scope.promotion.$promise.then(function (result) {
				result.startDate = new Date(
										$filter('date')(new Date(result.startDate),'yyyy'), 
										$filter('date')(new Date(result.startDate),'MM')-1, 
										$filter('date')(new Date(result.startDate),'dd'), 
										$filter('date')(new Date(result.startDate),'HH'), 
										$filter('date')(new Date(result.startDate),'mm'), 
										$filter('date')(new Date(result.startDate),'ss'));	
				result.endDate = new Date(
										$filter('date')(new Date(result.endDate),'yyyy'), 
										$filter('date')(new Date(result.endDate),'MM')-1, 
										$filter('date')(new Date(result.endDate),'dd'), 
										$filter('date')(new Date(result.endDate),'HH'), 
										$filter('date')(new Date(result.endDate),'mm'), 
										$filter('date')(new Date(result.endDate),'ss'));
			});
		};		
		$scope.update=function(){
			$scope.promotion.$update(function(){
				$scope.showMsg = true;
				$scope.formatDatetime();
			});
		};
		$scope.load=function(){
			$scope.promotion=Promotion.get({id:$stateParams.id});
			$scope.formatDatetime();
		};
		
		$scope.load();
	})
	
	.controller('ShopListController',function($scope,$state,$window,showDialogService,Shop,menuService){
		console.log("ShopListController start...");

		$scope.delete=function(shop){
			if(showDialogService.showDialog('Do you confirm to delete?')){
				shop.$delete(function(){
					$scope.shops=Shop.query();
				});
			}
		};

		menuService.close();		
		$scope.shops=Shop.query();		
	})
	.controller('ShopNewController',function($scope,$state,$stateParams,Shop,menuService){
		console.log("ShopNewController start...");
		
		$scope.add=function(){
			$scope.shop.$save(function(){
				$scope.showMsg = true;
			});
		};
		
		menuService.close();
		$scope.shop=new Shop();
	})
	.controller('ShopEditController',function($scope,$state,$stateParams,Shop){
		console.log("ShopEditController start...");
		
		$scope.update=function(){
			$scope.shop.$update(function(){
				$scope.showMsg = true;
			});
		};
		$scope.load=function(){
			$scope.shop=Shop.get({id:$stateParams.id});
		};

		$scope.load();
	})	
	;